{% extends 'netbox_dns/zone_base.html' %}
{% load helpers %}
{% load render_table from django_tables2 %}

{% block content-wrapper %}
  <div class="tab-content">

    {# Object list #}
    <div class="tab-pane show active" id="object-list" role="tabpanel" aria-labelledby="object-list-tab">

      {# "Select all" form #}
      {% if table.paginator.num_pages > 1 %}
        {% with bulk_edit_url="plugins:netbox_dns:record_bulk_edit" bulk_delete_url="plugins:netbox_dns:record_bulk_delete" %}
          <div id="select-all-box" class="d-none card noprint">
            <form method="post" class="form col-md-12">
              {% csrf_token %}
              <div class="card-body">
                <div class="float-end">
                  {% if bulk_edit_url and permissions.change %}
                    <button type="submit" name="_edit" formaction="{% url bulk_edit_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-warning btn-sm" disabled>
                      <span class="mdi mdi-pencil" aria-hidden="true"></span> Edit All
                    </button>
                  {% endif %}
                  {% if bulk_delete_url and permissions.delete %}
                    <button type="submit" name="_delete" formaction="{% url bulk_delete_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-danger btn-sm" disabled>
                      <span class="mdi mdi-trash-can-outline" aria-hidden="true"></span> Delete All
                    </button>
                  {% endif %}
                </div>
                <div class="form-check">
                  <input type="checkbox" id="select-all" name="_all" class="form-check-input" />
                  <label for="select-all" class="form-check-label">
                    Select <strong>all {{ table.rows|length }} {{ table.data.verbose_name_plural }}</strong> matching query
                  </label>
                </div>
              </div>
            </form>
          </div>
        {% endwith %}
      {% endif %}

      <div class="row mb-3 justify-content-between">
        <div class="table-controls noprint col col-md-12 mb-0">
          {% if request.user.is_authenticated %}
            <div class="table-configure input-group input-group-sm">
              <button
                type="button"
                data-bs-toggle="modal"
                title="Configure Table"
                data-bs-target="#ZoneRecordTable_config"
                class="btn btn-sm btn-outline-dark"
              >
                <i class="mdi mdi-cog"></i> Configure Table
              </button>
            </div>
          {% endif %}
        </div>
      </div>

      <form method="post" class="form form-horizontal">
        {% csrf_token %}
        <input type="hidden" name="return_url" value="{% if return_url %}{{ return_url }}{% else %}{{ request.path }}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}{% endif %}" />

        {# Object table #}
        <div class="card">
          <div class="card-body">
            <div class="table-responsive">
              {% render_table table %}
            </div>
          </div>
        </div>

        {# Form buttons #}
        {% if permissions.change or permissions.delete %}
          {% with bulk_edit_url="plugins:netbox_dns:record_bulk_edit" bulk_delete_url="plugins:netbox_dns:record_bulk_delete" %}
            <div class="noprint bulk-buttons">
              <div class="bulk-button-group">
                {% block bulk_buttons %}{% endblock %}
                {% if bulk_edit_url and permissions.change %}
                  <button type="submit" name="_edit" formaction="{% url bulk_edit_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-warning btn-sm">
                    <i class="mdi mdi-pencil" aria-hidden="true"></i> Edit Selected
                  </button>
                {% endif %}
                {% if bulk_delete_url and permissions.delete %}
                  <button type="submit" name="_delete" formaction="{% url bulk_delete_url %}{% if request.GET %}?{{ request.GET.urlencode }}{% endif %}" class="btn btn-danger btn-sm">
                    <i class="mdi mdi-trash-can-outline" aria-hidden="true"></i> Delete Selected
                  </button>
                {% endif %}
              </div>
            </div>
          {% endwith %}
        {% endif %}

      </form>

      {# Paginator #}
      {% include 'inc/paginator.html' with paginator=table.paginator page=table.page %}
    </div>
  </div>

  {# Table config form #}
  {% table_config_form table table_name="ZoneRecordTable" %}

{% endblock content-wrapper %}
