# Generated by Django 3.2.8 on 2021-10-20 11:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="zone",
            name="default_ttl",
            field=models.PositiveIntegerField(blank=True, default=86400),
            preserve_default=False,
        ),
    ]
