# Generated by Django 3.2.9 on 2021-12-13 20:44

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("netbox_dns", "0006_zone_soa_serial_auto"),
    ]

    operations = [
        migrations.AlterField(
            model_name="zone",
            name="soa_serial_auto",
            field=models.BooleanField(default=True),
        ),
    ]
