# Generated by Django 4.0.2 on 2022-02-09 15:44

from django.db import migrations, models
import taggit.managers


class Migration(migrations.Migration):

    dependencies = [
        ("extras", "0072_created_datetimefield"),
        ("netbox_dns", "0008_zone_status_names"),
    ]

    operations = [
        migrations.AlterField(
            model_name="nameserver",
            name="created",
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name="nameserver",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False
            ),
        ),
        migrations.AlterField(
            model_name="nameserver",
            name="tags",
            field=taggit.managers.TaggableManager(
                through="extras.TaggedItem", to="extras.Tag"
            ),
        ),
        migrations.AlterField(
            model_name="record",
            name="created",
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name="record",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False
            ),
        ),
        migrations.AlterField(
            model_name="record",
            name="tags",
            field=taggit.managers.TaggableManager(
                through="extras.TaggedItem", to="extras.Tag"
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="created",
            field=models.DateTimeField(auto_now_add=True, null=True),
        ),
        migrations.AlterField(
            model_name="zone",
            name="id",
            field=models.BigAutoField(
                auto_created=True, primary_key=True, serialize=False
            ),
        ),
        migrations.AlterField(
            model_name="zone",
            name="tags",
            field=taggit.managers.TaggableManager(
                through="extras.TaggedItem", to="extras.Tag"
            ),
        ),
    ]
